@@ -13,8 +13,8 @@ class SymptomMatcher:
         self.max_n_gram = n_grams
 
         self.dep_symp_dict = self.get_extend_dep_symp_dict()
-        self.dep_keys = get_dep_keys()
-        self.list_of_symptoms = self.get_list_of_symptoms()
+        # self.dep_keys = get_dep_keys()
+        # self.list_of_symptoms = self.get_list_of_symptoms()
 
         # for fuzzy match
         self.threshold = threshold
@@ -36,28 +36,47 @@ class SymptomMatcher:
             res = self.format_output(str, res[0], res[1])
             return res
 
-    def extract_symptoms(self, utterance, get_dep_keys=False, top_k=3):
+    def extract_symptoms(self, utterance, input_symptoms= None, input_dep_keys=None, get_dep_keys=False, top_k=3):
         '''
         get_dep_keys : get_dep_keys from utterance
         top_k : use whenever get_dep_keys is True
         '''
         utterance = self.preprocess(utterance).lower()
 
-        symptoms = self.get_symptoms(utterance)
-        if symptoms != [] and get_dep_keys:
-            data = []
-            for ent in symptoms:
-                data.append(ent['value'])
-            result = self.get_department_from_symptoms(data, top_k)
-        elif symptoms == []:
-            result = 'No symptoms are existed or some symptoms are not updated in database'
+        if input_symptoms is not None or input_dep_keys is not None:
+            input_symptoms = self.unify_input_symptoms(input_symptoms, input_dep_keys) # list
+
+        if input_symptoms is not None:
+            symptoms = self.get_symptoms(utterance,input_symptoms=input_symptoms)
+            if symptoms != [] and get_dep_keys:
+                data = []
+                for ent in symptoms:
+                    data.append(ent['value'])
+                result = self.get_department_from_symptoms(data, input_dep_keys, top_k)
+            elif symptoms == []:
+                result = 'No symptoms are existed or some symptoms are not updated in database'
+            else:
+                result = {}
+                result['entities'] = symptoms
+
+            return result
         else:
-            result = {}
-            result['entities'] = symptoms
 
-        return result
+            symptoms = self.get_symptoms(utterance)
+            if symptoms != [] and get_dep_keys:
+                data = []
+                for ent in symptoms:
+                    data.append(ent['value'])
+                result = self.get_department_from_symptoms(data, input_dep_keys, top_k)
+            elif symptoms == []:
+                result = 'No symptoms are existed or some symptoms are not updated in database'
+            else:
+                result = {}
+                result['entities'] = symptoms
 
-    def get_symptoms(self, utterance):
+            return result
+
+    def get_symptoms(self, utterance, input_symptoms=None):
         result = []
         history = []
         for i in range(1,self.max_n_gram):
@@ -67,7 +86,7 @@ class SymptomMatcher:
                     item = ' '.join(item)
                 else:
                     item = item[0]
-                symptom = self.fuzzy_matching(item, threshold=85)
+                symptom = self.fuzzy_matching(item, input_symptoms=input_symptoms, threshold=85)
                 if symptom != []:
                     symptom = symptom[1]
                     start = utterance.find(item)
@@ -93,9 +112,14 @@ class SymptomMatcher:
                     return (self.keys[k], token)
         return None
 
-    def fuzzy_matching(self, str, threshold):
+    def fuzzy_matching(self, str, input_symptoms=None, threshold=75):
         scores = []
-        for k, v in self.dep_symp_dict.items():
+        dep_symp_dict = self.dep_symp_dict
+        if input_symptoms is not None:
+            dep_symp_dict = {}
+            dep_symp_dict['A001'] = input_symptoms
+
+        for k, v in dep_symp_dict.items():
             ratios = [fuzz.ratio(str, value)
                       for value in v]  # ensure both are in string
             scores.append({"key": k, "score": max(ratios),
@@ -108,7 +132,7 @@ class SymptomMatcher:
         sorted_filtered_scores = sorted(
             filtered_scores, key=lambda k: k['score'], reverse=True)
 
-        return (self.dep_keys[sorted_filtered_scores[0]['key']], sorted_filtered_scores[0]['value'])
+        return (sorted_filtered_scores[0]['key'], sorted_filtered_scores[0]['value'])
 
     def format_output(self, text, key, value):
         return {
@@ -124,13 +148,17 @@ class SymptomMatcher:
                 cnt += 1
         return cnt/len(symptoms)
 
-    def get_department_from_symptoms(self, symptoms, top_k=3):
+    def get_department_from_symptoms(self, symptoms,input_dep_keys=None, top_k=3):
         '''
         symptoms : list of symptoms
         '''
         score_list = []
 
-        for i, (dep, dep_symptoms) in enumerate(self.dep_symp_dict.items()):
+        dep_symp_dict = self.dep_symp_dict
+        if input_dep_keys is not None:
+            dep_symp_dict = input_dep_keys
+
+        for i, (dep, dep_symptoms) in enumerate(dep_symp_dict.items()):
             score = self.get_department_score(symptoms, dep_symptoms)
             score_list.append({
                 'score': score,
@@ -138,7 +166,7 @@ class SymptomMatcher:
         filtered_scores = sorted(
             score_list, key=lambda k: k['score'], reverse=True)
 
-        res = [(self.dep_keys[item['key']], item['score'])
+        res = [(item['key'], item['score'])
                for item in filtered_scores[:top_k]]
 
         return res
@@ -166,3 +194,25 @@ class SymptomMatcher:
             d[k] = v
             d[k].extend(d2[k])
         return d
+
+    # def set_list_of_symptoms(self, input_list):
+    #     self.list_of_symptoms = input_list
+
+    def set_dep_symp_database(self, input_dict):
+        '''
+            input_dict = {
+                'SP001' : ['sot','buon ngu','chong mat'],
+                'SP002' : ['sot','buon ngu','chong mat'],
+            }
+        '''
+        self.dep_symp_dict = input_dict
+    
+    def unify_input_symptoms(self,input_symptoms=None, input_dep_keys=None):
+        res = []
+        if input_dep_keys is not None:
+            for k, v in input_dep_keys.items():
+                res.extend(v)
+        if input_symptoms is not None:
+            res.extend(input_symptoms)
+        res = list(set(res))
+        return res
\ No newline at end of file
